@@ -71,7 +71,7 @@ def send_notifications(email, sender, email_configuration):
     # # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
     # email_html = open(file_name)
-    BODY_HTML = open('\media' + file_name).read().format(cover=cover,
+    BODY_HTML = open('media/' + file_name).read().format(cover=cover,
                                                          logo=logo,
                                                          paragraph=paragraph)
     # Define the attachment part and encode it using MIMEApplication.
